@@ -90,9 +90,9 @@ def get_metric_summary(with_description):
     return summary
 
 # For local setup: clone code and pip setup.py install
-config_dir = os.path.join(os.path.dirname(pyneval.__file__), '../config/pyneval', )
+# config_dir = os.path.join(os.path.dirname(pyneval.__file__), '../config/pyneval', )
 # For Pypi:
-# config_dir = os.path.join(sys.prefix, 'config/pyneval', )
+config_dir = os.path.join(sys.prefix, 'config/pyneval', )
 
 def get_metric_config_path(metric, root_dir):
     return os.path.join(config_dir, get_metric_config(metric)['config'])
